@@ -19,6 +19,8 @@ class Defaults(namespace):
     CACHEOPS_PREFIX = lambda query: ''
     CACHEOPS_LRU = False
     CACHEOPS_DEGRADE_ON_FAILURE = False
+    CACHEOPS_SENTINEL = {}
+
     FILE_CACHE_DIR = '/tmp/cacheops_file_cache'
     FILE_CACHE_TIMEOUT = 60*60*24*30
 
@@ -74,6 +76,7 @@ def model_profile(model):
     """
     Returns cacheops profile for a model
     """
+    # Django migrations these fake models, we don't want to cache them
     if model.__module__ == '__fake__':
         return None
 
