@@ -1,4 +1,5 @@
-local key = KEYS[1]
+local prefix = KEYS[1]
+local key = KEYS[2]
 local data = ARGV[1]
 local dnfs = cjson.decode(ARGV[2])
 local timeout = tonumber(ARGV[3])
@@ -9,10 +10,11 @@ redis.call('setex', key, timeout, data)
 
 
 -- A pair of funcs
+-- NOTE: we depend here on keys order being stable
 local conj_schema = function (conj)
     local parts = {}
-    for _, eq in ipairs(conj) do
-        table.insert(parts, eq[1])
+    for field, _ in pairs(conj) do
+        table.insert(parts, field)
     end
 
     return table.concat(parts, ',')
@@ -20,21 +22,19 @@ end
 
 local conj_cache_key = function (db_table, conj)
     local parts = {}
-    for _, eq in ipairs(conj) do
-        table.insert(parts, eq[1] .. '=' .. tostring(eq[2]))
+    for field, val in pairs(conj) do
+        table.insert(parts, field .. '=' .. tostring(val))
     end
 
-    return 'conj:' .. db_table .. ':' .. table.concat(parts, '&')
+    return prefix .. 'conj:' .. db_table .. ':' .. table.concat(parts, '&')
 end
 
 
 -- Update schemes and invalidators
-for _, disj_pair in ipairs(dnfs) do
-    local db_table = disj_pair[1]
-    local disj = disj_pair[2]
+for db_table, disj in pairs(dnfs) do
     for _, conj in ipairs(disj) do
         -- Ensure scheme is known
-        redis.call('sadd', 'schemes:' .. db_table, conj_schema(conj))
+        redis.call('sadd', prefix .. 'schemes:' .. db_table, conj_schema(conj))
 
         -- Add new cache_key to list of dependencies
         local conj_key = conj_cache_key(db_table, conj)
