@@ -1,3 +1,4 @@
+local prefix = KEYS[1]
 local db_table = ARGV[1]
 local obj = cjson.decode(ARGV[2])
 
@@ -9,7 +10,7 @@ local conj_cache_key = function (db_table, scheme, obj)
         table.insert(parts, field .. '=' .. tostring(obj[field]))
     end
 
-    return 'conj:' .. db_table .. ':' .. table.concat(parts, '&')
+    return prefix .. 'conj:' .. db_table .. ':' .. table.concat(parts, '&')
 end
 
 local call_in_chunks = function (command, args)
@@ -22,7 +23,7 @@ end
 
 -- Calculate conj keys
 local conj_keys = {}
-local schemes = redis.call('smembers', 'schemes:' .. db_table)
+local schemes = redis.call('smembers', prefix .. 'schemes:' .. db_table)
 for _, scheme in ipairs(schemes) do
     table.insert(conj_keys, conj_cache_key(db_table, scheme, obj))
 end
