@@ -256,11 +256,11 @@ class QuerySetMixin(object):
                 return self
 
         def clone(self, klass=None, setup=False, **kwargs):
-            if '_cacheprofile' in self.__dict__ and self._cacheprofile:
-                kwargs.setdefault('_cacheprofile', self._cacheprofile.copy())
-
             clone = self._no_monkey._clone(self, klass, setup, **kwargs)
             clone._cloning = self._cloning - 1 if self._cloning else 0
+            # NOTE: need to copy profile so that clone changes won't affect this queryset
+            if self.__dict__.get('_cacheprofile'):
+                clone._cacheprofile = self._cacheprofile.copy()
             return clone
 
     def _fetch_all(self):
@@ -319,7 +319,7 @@ class QuerySetMixin(object):
             # Don't bother with Q-objects, select_related and previous filters,
             # simple gets - thats what we are really up to here.
             #
-            # TODO: this checks are far from adequete, at least these are missed:
+            # TODO: this checks are far from adequate, at least these are missed:
             #       - settings.CACHEOPS_ENABLED
             #       - self._for_write
             #       - self._fields (values, values_list)
@@ -386,8 +386,11 @@ class QuerySetMixin(object):
         rows = clone.update(**kwargs)
 
         # TODO: do not refetch objects but update with kwargs in simple cases?
+        # We use clone database to fetch new states, as this is the db they were written to.
+        # Using router with new_objects may fail, using self may return slave during lag.
         pks = {obj.pk for obj in objects}
-        for obj in chain(objects, self.model.objects.filter(pk__in=pks)):
+        new_objects = self.model.objects.filter(pk__in=pks).using(clone.db)
+        for obj in chain(objects, new_objects):
             invalidate_obj(obj)
         return rows
 
@@ -414,6 +417,7 @@ class ManagerMixin(object):
         if not hasattr(module, cls.__name__):
             setattr(module, cls.__name__, cls)
 
+    # This is probably still needed if models are created dynamically
     def contribute_to_class(self, cls, name):
         self._no_monkey.contribute_to_class(self, cls, name)
         # Django migrations create lots of fake models, just skip them
@@ -425,7 +429,8 @@ class ManagerMixin(object):
     def _pre_save(self, sender, instance, **kwargs):
         if not (instance.pk is None or instance._state.adding or no_invalidation.active):
             try:
-                _old_objs.__dict__[sender, instance.pk] = sender.objects.get(pk=instance.pk)
+                _old_objs.__dict__[sender, instance.pk] = sender.objects. \
+                    using(instance._state.db).get(pk=instance.pk)
             except sender.DoesNotExist:
                 pass
 
@@ -577,3 +582,11 @@ def install_cacheops():
     if six.PY3:
         import copyreg
         copyreg.pickle(memoryview, lambda b: (memoryview, (bytes(b),)))
+
+    # Fix random ordered dict keys producing different SQL for same QuerySet
+    if (3, 3) <= sys.version_info < (3, 6):
+        from django.db.models.query_utils import Q
+
+        def Q__init__(self, *args, **kwargs):  # noqa
+            super(Q, self).__init__(children=list(args) + list(sorted(kwargs.items())))
+        Q.__init__ = Q__init__
