@@ -3,9 +3,11 @@ import warnings
 from contextlib import contextmanager
 import six
 
+from django.core.exceptions import ImproperlyConfigured
+
 from funcy import decorator, identity, memoize, LazyObject
 import redis
-
+from redis.sentinel import Sentinel
 from .conf import settings
 
 
@@ -79,6 +81,21 @@ class CacheopsRedis(redis.StrictRedis):
 
 @LazyObject
 def redis_client():
+    if settings.CACHEOPS_REDIS and settings.CACHEOPS_SENTINEL:
+        raise ImproperlyConfigured("CACHEOPS_REDIS and CACHEOPS_SENTINEL are mutually exclusive")
+
+    if settings.CACHEOPS_SENTINEL:
+        if not {'locations', 'service_name'} <= set(settings.CACHEOPS_SENTINEL):
+            raise ImproperlyConfigured("Specify locations and service_name for CACHEOPS_SENTINEL")
+
+        sentinel = Sentinel(settings.CACHEOPS_SENTINEL['locations'])
+        return sentinel.master_for(
+            settings.CACHEOPS_SENTINEL['service_name'],
+            redis_class=CacheopsRedis,
+            db=settings.CACHEOPS_SENTINEL.get('db', 0),
+            socket_timeout=settings.CACHEOPS_SENTINEL.get('socket_timeout')
+        )
+
     # Allow client connection settings to be specified by a URL.
     if isinstance(settings.CACHEOPS_REDIS, six.string_types):
         return CacheopsRedis.from_url(settings.CACHEOPS_REDIS)
