@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 from itertools import product
 from funcy import group_by, join_with
-from funcy.py3 import lcat, lmap, zip_dicts
+from funcy.py3 import lcat, lmap
 
 import django
 from django.db.models.query import QuerySet
@@ -16,7 +16,7 @@ except ImportError:
     class EverythingNode(object):
         pass
 
-from .utils import family_has_profile, table_to_model, NOT_SERIALIZED_FIELDS
+from .utils import NOT_SERIALIZED_FIELDS
 
 
 LONG_DISJUNCTION = 8
@@ -114,7 +114,7 @@ def dnfs(qs):
         # NOTE: a more elaborate DNF reduction is not really needed,
         #       just keep your querysets sane.
         if not all(cleaned):
-            return [[]]
+            return [{}]
         return cleaned
 
     def query_dnf(query):
@@ -127,8 +127,8 @@ def dnfs(qs):
 
         # NOTE: we exclude content_type as it never changes and will hold dead invalidation info
         main_alias = query.model._meta.db_table
-        aliases = {alias for alias, (join, cnt) in zip_dicts(query.alias_map, query.alias_refcount)
-                   if cnt and family_has_profile(table_to_model(join.table_name))} \
+        aliases = {alias for alias, join in query.alias_map.items()
+                   if query.alias_refcount[alias]} \
                 | {main_alias} - {'django_content_type'}
         tables = group_by(table_for, aliases)
         return {table: clean_dnf(dnf, table_aliases) for table, table_aliases in tables.items()}
