@@ -2,11 +2,10 @@
 import re
 import json
 import inspect
-from funcy import memoize, compose, wraps, any, any_fn, select_values, make_lookuper
+from funcy import memoize, compose, wraps, any, any_fn, select_values
 from funcy.py3 import lmapcat
 from .cross import md5hex
 
-from django.apps import apps
 from django.db import models
 from django.http import HttpRequest
 
@@ -22,6 +21,9 @@ NOT_SERIALIZED_FIELDS = (
 )
 
 
+def get_concrete_model(model):
+    return next(b for b in model.__mro__ if issubclass(b, models.Model) and not b._meta.abstract)
+
 def model_family(model):
     """
     Returns a list of all proxy models, including subclasess, superclassses and siblings.
@@ -31,7 +33,9 @@ def model_family(model):
 
     # NOTE: we also list multitable submodels here, we just don't care.
     #       Cacheops doesn't support them anyway.
-    return class_tree(model._meta.concrete_model)
+    # NOTE: when this is called in Manager.contribute_to_class()
+    #       ._meta.concrete_model might still be None
+    return class_tree(model._meta.concrete_model or get_concrete_model(model))
 
 
 @memoize
@@ -39,14 +43,6 @@ def family_has_profile(cls):
     return any(model_profile, model_family(cls))
 
 
-@make_lookuper
-def table_to_model():
-    d = {m._meta.db_table: m for m in apps.get_models(include_auto_created=True)}
-    from django.db.migrations.recorder import MigrationRecorder
-    d['django_migrations'] = MigrationRecorder.Migration
-    return d
-
-
 class MonkeyProxy(object):
     pass
 
@@ -152,6 +148,7 @@ NEWLINE_BETWEEN_TAGS = mark_safe('>\n<')
 SPACE_BETWEEN_TAGS = mark_safe('> <')
 
 def carefully_strip_whitespace(text):
-    text = re.sub(r'>\s*\n\s*<', NEWLINE_BETWEEN_TAGS, text)
-    text = re.sub(r'>\s{2,}<', SPACE_BETWEEN_TAGS, text)
+    def repl(m):
+        return NEWLINE_BETWEEN_TAGS if '\n' in m.group(0) else SPACE_BETWEEN_TAGS
+    text = re.sub(r'>\s{2,}<', repl, text)
     return text
